@@ -55,3 +55,12 @@ def get_session_path(bot: DeltaBot) -> str:
     if not os.path.exists(path):
         os.makedirs(path)
     return os.path.join(path, "telegram.session")
+
+
+def shorten_text(text: str, width: int, placeholder: str = "…") -> str:
+    text = " ".join(text.split())
+    if len(text) > width:
+        width -= len(placeholder)
+        assert width > 0, "placeholder can't be bigger than width"
+        text = text[:width].strip() + placeholder
+    return text
